@@ -279,17 +279,6 @@ static void error_dialog(gchar * val)
     gtk_dialog_run(GTK_DIALOG(w));
     gtk_widget_destroy(w);
 }
-static void fetching_dialog(gchar * val)
-{
-    GtkWidget * w;
-    w = gtk_message_dialog_new(GTK_WINDOW(mainWindow),
-            GTK_DIALOG_DESTROY_WITH_PARENT,
-            GTK_MESSAGE_INFO,
-            GTK_BUTTONS_OK,
-            val);
-    gtk_dialog_run(GTK_DIALOG(w));
-    gtk_widget_destroy(w);
-}
 static void cb_load(GtkWidget *w, gpointer d)
 {
     GKeyFile * f;
@@ -600,19 +589,19 @@ static void cb_delete(GtkWidget *w, gpointer d)
         }
         else
         {
-            GDir * d;
+            GDir * dir;
             gchar * ot, * mt, * pt;
             pt = g_strdup_printf("%s/.emerald/themes/%s/",g_get_home_dir(),at);
-            d = g_dir_open(pt,0,NULL);
-            while (d && (ot = (gchar *)g_dir_read_name(d)))
+            dir = g_dir_open(pt,0,NULL);
+            while (dir && (ot = (gchar *)g_dir_read_name(dir)))
             {
                 mt = g_strdup_printf("%s/%s",pt,ot);
                 g_unlink(mt);
                 g_free(mt);
             }
-            if (d)
+            if (dir)
             {
-                g_dir_close(d);
+                g_dir_close(dir);
                 g_rmdir(pt);
             }
             g_free(pt);
@@ -1444,7 +1433,7 @@ void import_cache(GtkWidget * progbar)
 gboolean watcher_func(gpointer p)
 {
     FetcherInfo * f = p;
-    int stat;
+
     gtk_progress_bar_pulse(GTK_PROGRESS_BAR(f->progbar));
     if (waitpid(f->pd,NULL,WNOHANG)!=0)
     {
@@ -1485,7 +1474,7 @@ void fetch_svn()
 }
 void fetch_gpl_svn()
 {
-	svnpath="svn://svn.beryl-project.org/beryl/trunk/emerald-themes-repo";
+	svnpath="http://emerald-themes.googlecode.com/svn/trunk/emerald-themes-repo";
 	themecache=g_strconcat(g_get_home_dir(),"/.emerald/themecache",NULL);
 	fetch_svn();
 }
@@ -1501,9 +1490,9 @@ void cb_quit(GtkWidget * w, gpointer p)
 }
 void layout_upper_pane(GtkWidget * vbox)
 {
-    GtkWidget * hbox;
+    //GtkWidget * hbox;
 
-    hbox = gtk_hbox_new(FALSE,2);
+    //hbox = gtk_hbox_new(FALSE,2);
     //gtk_box_pack_startC(vbox,hbox,TRUE,TRUE,0);
 
     gtk_box_pack_startC(vbox,build_tree_view(),TRUE,TRUE,0);
@@ -1566,7 +1555,7 @@ void layout_themes_pane(GtkWidget * vbox)
     gtk_box_pack_startC(vbox,notebook,TRUE,TRUE,0);
     layout_upper_pane(build_notebook_page(_("Themes"),notebook));
     layout_lower_pane(build_notebook_page(_("Edit Themes"),notebook));
-	layout_repo_pane(build_notebook_page(_("Repositories"),notebook));
+//	layout_repo_pane(build_notebook_page(_("Repositories"),notebook));
 	
 }
 GtkWidget* create_filechooserdialog1 (char *input)
